=====================
WIM Create Web Images
=====================

.. image:: https://badge.fury.io/py/wim.png
    :target: http://badge.fury.io/py/wim

.. image:: https://travis-ci.org/yaph/wim.png?branch=master
        :target: https://travis-ci.org/yaph/wim

.. image:: https://pypip.in/d/wim/badge.png
        :target: https://pypi.python.org/pypi/wim


wim is a command line tool to create images for the Web.

Usage
-----

.. code:: Bash

    wim input.png -t 'add this text at the bottom'

Features
--------

* Add text at the bottom of the image.

Meta
----

* Free software: MIT license
* Documentation: https://pythonhosted.org/wim/